@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon_service - remote control daemon for Nokia N900 phone#
-# $Id: smscon_service.py 25 2011-12-14 23:58:51Z yablacky $
+# $Id: smscon_service.py 58 2011-12-21 01:51:26Z yablacky $
 ##############################################################
 
 # standard modules
@@ -157,7 +157,7 @@ def OnSmsReceived(PDUmessage, MessageCenter, SomeString, SenderNumber):
 def SMSsend(RecipientNumber, MessageList, SuccessLogMsg):
     """
     Send SMS message to RecipientNumber.
-    @return bool False iff the message has definitely not been sent. True otherwise.
+    @return bool False if the message has definitely not been sent. True otherwise.
     """
     if not RecipientNumber:
         return False
@@ -172,8 +172,12 @@ def SMSsend(RecipientNumber, MessageList, SuccessLogMsg):
         LOGGER.warning('Trying to re-send SMS message after %s minutes.' % float(smscnf.RESENDTIME))
         tryCount = { 'value': 0 }
         gobject.timeout_add(int(float(smscnf.RESENDTIME)) * 60000,
-                            lambda a,b,c,**kwargs: not SendToGSMmodem(a,b,c,**kwargs),
-                            RecipientNumber, MessageText, SuccessLogMsg, TryCount = tryCount)
+                            lambda args: not SendToGSMmodem(**args), dict(
+                                RecipientNumber   = RecipientNumber,
+                                Message           = MessageText,
+                                SuccessLogMsg     = SuccessLogMsg,
+                                TryCount          = tryCount,
+                            ))
         return True
 
     # Message must be split
@@ -259,21 +263,22 @@ def SendToGSMmodem(RecipientNumber, Message, SuccessLogMsg, TryCount = None):
     Send SMS message to GSM modem.
     @return bool Success indicator
     """
+    RetryInfo = ''
     if TryCount:
         TryCount['value'] += 1
         if int(smscnf.RESENDMAXTRY) > 0 and TryCount['value'] > int(smscnf.RESENDMAXTRY):
             LOGGER.error('(SMS) Tried to send %d times. Limit %d reached. Giving up recipient=%s.' %
                             (TryCount['value'], int(smscnf.RESENDMAXTRY), RecipientNumber))
             return True
+        RetryInfo = " (%d. retry)" % TryCount['value']
+
     if SendSMSviaGSMmodem(RecipientNumber, Message):
         LOGGER.info(SuccessLogMsg.replace('{RECIPIENTNUMBER}', RecipientNumber))
         return True
     else:
-        LOGGER.error('Failed to send SMS to "%s".' % RecipientNumber)
+        LOGGER.error('Failed to send SMS to "%s"%s.' % (RecipientNumber, RetryInfo))
         return False
 
-##############################################################
-
 def DeOctifyMessage(inputBytes):
     """
     Decode inputBytes from SMS message according to GSM 03.38, GSM 7 bit default alphabet.
@@ -326,13 +331,13 @@ def DeOctifyMessage(inputBytes):
     return ''.join(outputText)
 
 #############################################
-#    email
+#   send email
 #############################################
 
 def EMAILsend(EmailTo, Subject, Text, SuccessLogMsg, **kwargs):
     """
     Send email; retry after <RESENDTIME> minutes if send failure.
-    @return bool False iff the message has definitely not been sent. True otherwise.
+    @return bool False if the message has definitely not been sent. True otherwise.
     """
     if SendToSMTPserver(EmailTo, Subject, Text, SuccessLogMsg, **kwargs):
         return True
@@ -341,8 +346,14 @@ def EMAILsend(EmailTo, Subject, Text, SuccessLogMsg, **kwargs):
     LOGGER.warning('Trying to re-send email message after %s minutes.' % float(smscnf.RESENDTIME))
     tryCount = { 'value': 0 }
     gobject.timeout_add(int(float(smscnf.RESENDTIME)) * 60000,
-                        lambda a,b,c,d,**kwargs: not SendToSMTPserver(a,b,c,d,**kwargs),
-                        EmailTo, Subject, Text, SuccessLogMsg, TryCount=tryCount, **kwargs)
+                        lambda args: not SendToSMTPserver(**args), dict(
+                            EmailTo       = EmailTo,
+                            Subject       = Subject,
+                            Text          = Text,
+                            SuccessLogMsg = SuccessLogMsg,
+                            TryCount      = tryCount,
+                            **kwargs
+                        ))
     return True
 
 def SendToSMTPserver(EmailTo, Subject, Text, SuccessLogMsg, Attachment = None, Attachhint = None, TryCount = None):
@@ -350,15 +361,17 @@ def SendToSMTPserver(EmailTo, Subject, Text, SuccessLogMsg, Attachment = None, A
     Send email to SMTP server.
     @return bool Success indicator
     """
+    RetryInfo = ''
     if TryCount:
         TryCount['value'] += 1
         if int(smscnf.RESENDMAXTRY) > 0 and TryCount['value'] > int(smscnf.RESENDMAXTRY):
             LOGGER.error('(EMAIL) Tried to send %d times. Limit %d reached. Giving up recipient=%s, subject=%s.' %
                             (TryCount['value'], int(smscnf.RESENDMAXTRY), EmailTo, Subject))
             return True
+        RetryInfo = " (%d. retry)" % TryCount['value']
 
     if not EmailTo:
-        LOGGER.error('(EMAIL) No recipient email address')
+        LOGGER.error('(EMAIL) No recipient email address%s.' % RetryInfo)
         return False
     # convert string list to string
     if type(Text).__name__ == 'list': Text = ''.join(Text)
@@ -419,7 +432,7 @@ def SendToSMTPserver(EmailTo, Subject, Text, SuccessLogMsg, Attachment = None, A
         Server = smtplib.SMTP(smscnf.MAILSERVER, smscnf.MAILPORT) 
         #Server.set_debuglevel(True)
     except (socket.error, smtplib.SMTPConnectError, smtplib.SMTPException):
-        LOGGER.error('(EMAIL) Mailserver connection failure.')
+        LOGGER.error('(EMAIL) Mailserver connection failure%s.' % RetryInfo)
         return False
 
     # identify to mail server
@@ -436,7 +449,7 @@ def SendToSMTPserver(EmailTo, Subject, Text, SuccessLogMsg, Attachment = None, A
             LOGGER.info('(EMAIL) Trying to login to "%s".' % smscnf.MAILSERVER)
             Server.login(smscnf.USER, smscnf.PASSWORD) 
         except smtplib.SMTPAuthenticationError:
-            LOGGER.error('(EMAIL) Wrong username/password.')
+            LOGGER.error('(EMAIL) Wrong username/password%s.' % RetryInfo)
             Server.quit()
             return False
 
@@ -446,7 +459,7 @@ def SendToSMTPserver(EmailTo, Subject, Text, SuccessLogMsg, Attachment = None, A
     except smtplib.SMTPException, e:
         LOGGER.error('(EMAIL) [%s].' % e)
         Server.quit()
-        LOGGER.error('(EMAIL) Mailserver connection closed.')
+        LOGGER.error('(EMAIL) Mailserver connection closed%s.' % RetryInfo)
         return False
 
     LOGGER.info(SuccessLogMsg)
@@ -608,13 +621,13 @@ def ProcessCommand(Command, SenderPhoneNumber=None, CommandOrigin=None, ExtraInf
         PerformAlarm()
 
     elif Command == smscnf.COM_RESTART:
-        RestartDeamon()
+        RestartDaemon()
 
     else:
         LOGGER.debug('Unknown command: [%s].' % Command)
 
 #############################################
-#   silence phone
+#   play sound file as an alarm
 #############################################
 
 def PerformAlarm():
@@ -665,8 +678,6 @@ def PerformAlarm():
 
     RevealThat('alarm', 'Alarm sound activated.')        
 
-#############################################
-
 def PlayAudio(File, Wait=False):
     """
     Play audio file in background.
@@ -777,8 +788,6 @@ def PerformShellScriptResult():
         RevealThat('script.log', 'Log file %s is attached. Script processes running: (%s).' % (Logname, PIDs),
                    Attachment = Logname, Attachhint = 'text/plain')
 
-#############################################
-
 def PerformDirectShellCommand(Command):
     """
     Run direct shell command and reply with notification message containing the command's output.
@@ -983,8 +992,6 @@ def GetNetworkConnectionType():
     else:                               Type = 'NONE' 
     return Type
 
-###############################
-
 def GetGPRSConnectionStatus():
     """
     Get status of GPRS data network.
@@ -999,8 +1006,6 @@ def GetGPRSConnectionStatus():
         if R[0]  == 'true': return True
     return None
 
-###############################
-
 def SetNetworkConnectionType(NewType):
     """
     Connect to GPRS data network.
@@ -1064,8 +1069,6 @@ def DisableConnection():
 
     time.sleep(DelaySeconds)
 
-###############################
-
 def GetGPRSname(): 
     """
     Get name of GPRS data connection from current inserted SIM card in Nokia phone.
@@ -1146,8 +1149,6 @@ def GetNetworks():
         
     return NetworkList
 
-###############################
-
 def RemindNetwork():
     """
     Save current active data network.
@@ -1163,8 +1164,6 @@ def RemindNetwork():
 
     LOGGER.info( 'Saved current %s network (%s) for restore.' % (Type, ConnectionName) )
 
-###############################
-
 def RestoreNetwork():
     """
     Re-enable previous stored data network.
@@ -1180,7 +1179,7 @@ def RestoreNetwork():
         DisableConnection()
 
 #############################################
-#    connect behaviour
+#   connect behaviour
 #############################################
 
 def SetAutoConnectBehaviour(NewBehaviour):
@@ -1251,7 +1250,7 @@ def SetAutoConnectBehaviour(NewBehaviour):
         return False
 
 #############################################
-#    power status
+#   power status
 #############################################
 
 def GetBatteryChargeInfo(TextOnly = True):
@@ -1293,7 +1292,8 @@ def LogBatteryChargeInfo():
     LOGGER.info(GetBatteryChargeInfo())
 
 #############################################
-#    SSH 
+#   SSH 
+#############################################
 
 def EnableSSHcontrol():
     """
@@ -1336,7 +1336,7 @@ def DisableSSHcontrol(Verbose = True):
         RevealThat('ssh', 'connection to "%s" terminated.' % smscnf.REMOTEHOST)
 
 #############################################
-#    GPS
+#   GPS
 #############################################
 
 def EnableGPStracking(Mode):
@@ -1536,7 +1536,7 @@ def CreateGoogleMap(Latitude, Longitude):
         return MapFilename
 
 #############################################
-#    SIM card
+#   SIM card
 #############################################
 
 def GetOperatorName():
@@ -1619,7 +1619,7 @@ def ValidateIMSI():
 def DoCommandLine():
     """
     Check arguments for smscon_daemon and perform corresponding actions.
-    @return bool True iff ok
+    @return bool True if ok
     """    
     def TellError(Msg):
         LOGGER.error(Msg)
@@ -1741,7 +1741,7 @@ def ExitDaemon(ExitReason = 'regularly'):
     LOGGER.critical('%s is stopping %s.' % (DaemonFile, ExitReason))
     sys.exit(1)
 
-def RestartDeamon():
+def RestartDaemon():
     """
     Restart smscon_daemon.
     @return void (does not return on success).
@@ -1951,7 +1951,6 @@ def LoadConfiguration():
         InstallSignalReceivers()
     return True
 
-
 def main():
     """
     Main function of smscon daemon. Does not return to caller.
@@ -1960,9 +1959,9 @@ def main():
 
     LOGGER.critical('%s is starting.' % DaemonFile)
     
-    signal.signal(smscon.smscon_deamon.TELL_TERMINATE,
+    signal.signal(smscon.smscon_daemon.TELL_TERMINATE,
                     lambda signum, stack_frame: ExitDaemon("on signal %s" % str(signum))  )
-    signal.signal(smscon.smscon_deamon.TELL_RELOAD,
+    signal.signal(smscon.smscon_daemon.TELL_RELOAD,
                     lambda signum, stack_frame: LoadConfiguration()                       )
     
     LoadConfiguration() or ExitDaemon('on config load error')
@@ -2088,7 +2087,7 @@ def main():
          will read and apply the new configuration automatically.
  NEW:    The smscon_daemon now maintains a "last known good" configuration and uses
          that as a fallback in case the "official" configuration of smscon can't
-         properly loaded by the deamon.
+         properly loaded by the daemon.
  NEW:    Camera picture and GSP Location requests do no longer force unconditional
          switching to GPRS network connection. The current connection will be used
          if the internet is reachable.
