@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon - remote control library for Nokia N900 phone       #
-# $Id: smsconlib.py 26 2011-12-15 00:37:17Z yablacky $
+# $Id: smsconlib.py 59 2011-12-21 01:52:57Z yablacky $
 ##############################################################
 
 # standard modules
@@ -21,7 +21,7 @@ def getSysBuildNameAndVersion(defaultName, defaultVersion = '999.1', headerInfo
     Analyze information from version control system to find out name and version of a branch.
     @param string defaultName Name to return if version information not recognized.
     @param string defaultVersion Version to return if version information not recognized.
-    @param string headerInfo Value from expanded $Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.3/src/opt/smscon/smsconlib.py 26 2011-12-15 00:37:17Z yablacky $ keyword to be analyzed.
+    @param string headerInfo Value from expanded $Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.4/src/opt/smscon/smsconlib.py 59 2011-12-21 01:52:57Z yablacky $ keyword to be analyzed.
     @param int dirLevel Number of extra dirs to walk up to find the one that contains version information (0 = parent dir).
     @return list (name, version) The name and version information.
     """
@@ -34,7 +34,7 @@ NAME = 'smscon'
 VERSION = '999.1'   # for trunk and private builds etc.
 
 NAME, VERSION = getSysBuildNameAndVersion(NAME, VERSION,
-    headerInfo  = '$Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.3/src/opt/smscon/smsconlib.py 26 2011-12-15 00:37:17Z yablacky $',
+    headerInfo  = '$Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.4/src/opt/smscon/smsconlib.py 59 2011-12-21 01:52:57Z yablacky $',
     dirLevels   = 3 )
     
 XDEBUG   = False        # cross debug (use only if not running on phone)
@@ -107,7 +107,7 @@ def DecodeAES(key, code):
 def pidof(ProcessName):
     """
     Determine the PID of processes that match a given name.
-    @return string Whitespace separater PID. Empty if none.
+    @return string Whitespace separator PID. Empty if none.
     """
     PIDs = os.popen('pidof "%s"' % ProcessName).read().strip('\n')
     if PIDs != '':
@@ -250,6 +250,7 @@ class Configuration(dict):
     ConfigParseFormat   = "^\\s*(\\S+)\\s*=\\s*([\"\']|)(.*?)\\2\\s*$"  # (ConfigVar, QuoteUsed, ConfigValue)
     CommentLineFormat   = "^\\s*(#.*)?$"
     CommentMakeFormat   = '# %s'
+    DefaultValueFormat  = None
     TabSize             = 0     # 0 means: calc dynamically on _ConfigVars
     _OPT_CRYPT          = 'E'
     _OPT_PLAIN          = 'P'
@@ -323,6 +324,7 @@ class Configuration(dict):
 
         ConfigValuePattern = re.compile(self.ConfigParseFormat)
         CommentLinePattern = re.compile(self.CommentLineFormat)
+        DefaultValuePattern= self.DefaultValueFormat and re.compile(self.DefaultValueFormat)
 
         ok = True
         for Line in ConfigLines:
@@ -347,13 +349,20 @@ class Configuration(dict):
                             self._upgradableConfigVars[ConfigVar] = True
                             ErrorMsg = 'Obsolete %s "%s" ignored.' % (self.ItemTypeName, ConfigVar)
                         else:
+                            EncryptedConfigValue = ConfigValue
                             if self._OPT_CRYPT in VarOptions:
                                 try:
                                     ConfigValue = self._decode(ConfigVar, ConfigValue)
                                 except:
                                     ErrorMsg = 'Failed to decode %s value for %s.' % (self.ItemTypeName, ConfigVar)
                             if Pattern and not re.match(Pattern, ConfigValue):
-                                self._warning('Value of %s "%s" does not match /%s/.' % (self.ItemTypeName, ConfigVar, Pattern))
+                                # If this is a known old-style default value, upgrade to new default value:
+                                if DefaultValuePattern and (re.match(DefaultValuePattern, ConfigValue)
+                                                        or  re.match(DefaultValuePattern, EncryptedConfigValue)):
+                                    self._upgradableConfigVars[ConfigVar] = True
+                                    ErrorMsg = 'Value of %s "%s" needs upgrade.' % (self.ItemTypeName, ConfigVar)
+                                else:
+                                    self._warning('Value of %s "%s" does not match /%s/.' % (self.ItemTypeName, ConfigVar, Pattern))
             if ErrorMsg:
                 if ok and not PrintContent: self._error('In %s:' % Thing)
                 print Line
@@ -361,7 +370,7 @@ class Configuration(dict):
             else:
                 if PrintContent:
                     print self._genConfigLine(ConfigVar, QuoteUsed+ConfigValue+QuoteUsed)
-                self[ConfigVar] = ConfigValue 
+                self[ConfigVar] = ConfigValue
         return ok
 
     def backup(self, Filename, Silent = False, Thing = None):
@@ -593,14 +602,18 @@ class Configuration(dict):
             key = keysToUpgrade.pop(0)
             Pattern, val, VarOptions = self._ConfigVars[key][0:3]
             if val != None:
+                useDefaultValue = True
                 if key in self:
                     if not (key in self._upgradableConfigVars):
                         continue    # up-to-date.
-                    if not (self._OPT_CRYPT in VarOptions):
-                        continue    # hmm.. this case should not happen.
-                    # This config var switched from plain to crypt
-                    val = self[key]
-                else:
+                    if self._OPT_CRYPT in VarOptions:
+                        # This config var switched from plain to crypt
+                        val = self[key]
+                        useDefaultValue = False
+                    else:
+                        # Should be the upgrade of an old style default value
+                        useDefaultValue = True
+                if useDefaultValue:
                     try:
                         val = self._calcDefaultValue(val)
                     except KeyError:
@@ -656,6 +669,7 @@ class UserConfiguration(Configuration):
     ItemTypeName        = "user setting"
     CreateTemplate      = '# %s user settings (initially written by version %s)\n' % (NAME, VERSION)
     SmsCommandPreFix    = 'COM_'       # _ConfigVars with that prefix define commands that can be sent via SMS
+    DefaultValueFormat  = '^\+?[X.@]+$' # '+XXXXXXXXXXX', 'XXXX@XXXXXXXX.XX', 'XXXX.XXXXXXXX.XX', ...
     _PhoneNumber        = '^\+?[0-9]+$'
     _CmdPattern         = ''
     _BoolPattern        = '^yes|no$'
@@ -820,9 +834,9 @@ def GetPhoneCode(CodeType):
         return None
 
 ##############################################################
-# smscon_deamon interface
+# smscon_daemon interface
 
-class smscon_deamon:
+class smscon_daemon:
     """
     Instances of this class are used to control the smscon daemon.
     """
@@ -860,7 +874,7 @@ class smscon_deamon:
     def tell(self, SignalNumber):
         """
         Signal smscon_daemon(s).
-        @return: string With list of deamons signaled.
+        @return: string With list of daemons signaled.
         """
         PIDs = self.runs()
         if PIDs:
